pub enum MoveType {
Drop,
Bounce,
None,
}Expand description
Designates the type of move.
A move can either be a drop or a bounce. A drop is a move that has three stages: the staring position, a piece that is replaced, and where that piece is dropped. A bounce is a move that only has two stages: the starting position and the ending position.
Variants