pub struct RootMove {
pub mv: Move,
pub score: f64,
pub threats: usize,
pub ply: i8,
}Expand description
Structure that defines a rootmove.
A rootmove is a move that can store other data associated with the root of a search tree. This data includes the ply of the move and
the score of the move.
Fields
mv: Movescore: f64threats: usizeply: i8Implementations